@@ -19,8 +19,8 @@
 ##'   \code{\link{storr}})
 ##' @export
 storr_external <- function(storage_driver, fetch_hook,
-                           default_namespace="objects") {
-  .R6_storr_external$new(storage_driver, fetch_hook, default_namespace)
+                           default_namespace = "objects") {
+  R6_storr_external$new(storage_driver, fetch_hook, default_namespace)
 }
 
 ## NOTE: This uses inheritence.  I actually think that this might be
@@ -34,23 +34,23 @@ storr_external <- function(storage_driver, fetch_hook,
 ##
 ## TODO: Support passing in an actual storr here, in which case we'd
 ## just take the driver element from it (possibly with a clone).
-.R6_storr_external <- R6::R6Class(
+R6_storr_external <- R6::R6Class(
   "storr_external",
-  inherit=.R6_storr,
-  public=list(
-    fetch_hook=NULL,
-    initialize=function(storage_driver, fetch_hook, default_namespace) {
+  inherit = R6_storr,
+  public = list(
+    fetch_hook = NULL,
+    initialize = function(storage_driver, fetch_hook, default_namespace) {
       super$initialize(storage_driver, default_namespace)
       self$fetch_hook <- check_external_fetch_hook(fetch_hook)
     },
-    ## NOTE: This is *always* using use_cache=TRUE in the set phase.
+    ## NOTE: This is *always* using use_cache = TRUE in the set phase.
     ## I think that's OK because it doesn't make a great deal of sense
     ## to expose use_cache in the get_hash function which generally
     ## will not touch the cache.
-    get_hash=function(key, namespace) {
+    get_hash = function(key, namespace) {
       if (!self$exists(key, namespace)) {
         value <- tryCatch(self$fetch_hook(key, namespace),
-                          error=function(e)
+                          error = function(e)
                             stop(KeyErrorExternal(key, namespace, e)))
         hash <- self$set(key, value, namespace)
         hash
@@ -60,10 +60,10 @@ storr_external <- function(storage_driver, fetch_hook,
     }))
 
 check_external_fetch_hook <- function(fetch_hook) {
+  ## NOTE: Could check here that there are two arguments, and that the
+  ## argument names are (key, namespace) but that seems overly
+  ## restrictive and hard to get right
   assert_function(fetch_hook)
-  if (!identical(names(formals(fetch_hook)), c("key", "namespace"))) {
-    stop("Function arguments must be 'key', 'namespace'")
-  }
   fetch_hook
 }
 
@@ -87,7 +87,7 @@ check_external_fetch_hook <- function(fetch_hook) {
 ##' @examples
 ##' hook <- fetch_hook_read(
 ##'     function(key, namespace) paste0(key, ".csv"),
-##'     function(filename) read.csv(filename, stringsAsFactors=FALSE))
+##'     function(filename) read.csv(filename, stringsAsFactors = FALSE))
 fetch_hook_read <- function(fpath, fread) {
   check_external_fetch_hook(fpath)
   assert_function(fread)
